@@ -507,7 +507,7 @@ class GLTF:
     def _embed_buffer_resources(self):
         if self.model.buffers is None:
             return
-        for i, buffer in enumerate(self.model.buffers):
+        for i, buffer in list(enumerate(self.model.buffers)):
             if buffer.uri is not None:
                 resource = self.get_resource(buffer.uri)
                 if resource is None:
@@ -517,7 +517,7 @@ class GLTF:
     def _embed_image_resources(self):
         if self.model.images is None:
             return
-        for i, image in enumerate(self.model.images):
+        for i, image in list(enumerate(self.model.images)):
             if image.uri is not None and image.bufferView is None:
                 resource = self.get_resource(image.uri)
                 if resource is None:
@@ -624,6 +624,8 @@ class GLTF:
                     if isinstance(resource, Base64Resource):
                         image.uri = None
                         image.mimeType = resource.mime_type
+                    elif isinstance(resource, FileResource):
+                        image.uri = None
 
     def _update_buffer_views_after_embedding_resource(self, buffer_index: int, offset: int):
         if self.model.bufferViews is not None:
